using System;
using System.Collections.Generic;
using System.Linq;
using System.Web.Mvc;
using CultureAudit.Models;
using Syncfusion.JavaScript.DataVisualization.Models;
using Syncfusion.JavaScript.DataVisualization;
using Syncfusion.XlsIO;
 
namespace CultureAudit.Areas.Admin.Controllers
{
    public class ClientReportsController : Controller
    {
        CultureAuditEntities db = new CultureAuditEntities();

        public ActionResult GenerateExcelDocument(int SurveyNumber, SurveyDefinition survey)
        {
            using (ExcelEngine excelEngine = new ExcelEngine())
            {
                string CompanyName = survey.GetCompany(SurveyNumber);
                // This is the number of questions for this group   this will be used to calculate positioning
                int numRows = survey.CountMatrixQuestions(SurveyNumber, 1);


                // Set the default application version as Excel 2016.
                excelEngine.Excel.DefaultVersion = ExcelVersion.Excel2016;
               
                // Create a workbook with a worksheet.
                IWorkbook workbook = excelEngine.Excel.Workbooks.Create(new string[] {"Q1", "Q2", "Q3", "Q4", "Q5", "Q6", "Q7", "Q8", "Q9", "Q10", "Q11", "Q12", "Q13", "Q14", "Q15", "Q16", "Q17", "Q18" });

                // Access first worksheet from the workbook instance.
                IWorksheet sheet1 = workbook.Worksheets[0];
                sheet1.Range["A1"].Text = "Attitudes & Perceptions";
                sheet1.Range["A1"].CellStyle.Font.Bold = true;
                sheet1.Range["A1"].CellStyle.Font.Size = 18;

                // Display table of data
                IList<SurveyScoresByGroup_Result> group1 = db.SurveyScoresByGroup(1, SurveyNumber).ToList();
                sheet1.ImportData(group1, 3, 1, true);
                sheet1.Range["A3:H3"].CellStyle.Font.Bold = true;
                // Get last row #
                int lastrow = Convert.ToInt16(sheet1.UsedRange.LastRow);
                int rownum = lastrow + 2;
                int b = rownum + numRows;   // this value needs to add the number of group questions to number of rows already on the worksheet
                int c = (numRows * 4) + rownum;
                AverageAnswerByGroup mod = new AverageAnswerByGroup();
                mod.GroupNumber = 1;
                mod.SurveyNumber = SurveyNumber;
                //We need to trick this  so we will pretend to display the data on the spreadsheet but will actually put chart there instead
                IList<AverageGroupAnswer_Result> data1 = mod.AverageGroupScores();
                sheet1.ImportData(data1, rownum, 1, true);
                IChartShape chart1 = sheet1.Charts.Add();
                chart1.ChartType = ExcelChartType.Bar_Clustered;
                string chartplacement = "A" + rownum.ToString() + ":B" + b.ToString();
          
                chart1.DataRange = sheet1.Range[chartplacement];
                chart1.PrimaryValueAxis.MinimumValue = 0;
                chart1.PrimaryValueAxis.MaximumValue = 5;
                chart1.PrimaryValueAxis.MinorUnit = .5;
                chart1.PrimaryValueAxis.Title = "Average Answer";
                chart1.ChartTitle = "";
                chart1.IsSeriesInRows = false;
                chart1.Legend.Position = ExcelLegendPosition.Bottom;
                chart1.Legend.Delete();
                chart1.TopRow = rownum;
                chart1.BottomRow = c;
                chart1.RightColumn = 15;
                chart1.LeftColumn = 1;
				FillSeriesColor(chart1);

                lastrow = Convert.ToInt16(sheet1.UsedRange.LastRow);
                b = lastrow +15;
                //sheet1.Range["A"+b].Text = "Comments";
                sheet1.Range["A" + b.ToString()].CellStyle.Font.Bold = true;
                sheet1.Range["A" + b.ToString()].CellStyle.Font.Size = 16;

                IList<ParticpantComments> q1Comments = survey.participantComments(SurveyNumber, 1);
                if (q1Comments.Count > 0)
                {
                    sheet1.ImportData(q1Comments, b, 1, true);
                }

                //------------------------------------------------------------------------------------------------------------Q2
                IWorksheet sheet2 = workbook.Worksheets[1];
                sheet2.Range["A1"].Text = "Name 3 things "+ CompanyName + " does well.";
                sheet2.Range["A1"].CellStyle.Font.Bold = true;
                sheet2.Range["A1"].CellStyle.Font.Size = 18;
                PhraseInstance phrase = new PhraseInstance();
                phrase.GroupNumber = 2;
                phrase.SurveyNumber = SurveyNumber;
                IList<DisplayInstancesOfPhrase_Result> DoesWell = phrase.PhrasesUsed();
                sheet2.ImportData(DoesWell, 3, 1, true);
                sheet2.Range["A3:B3"].CellStyle.Font.Bold = true;

                //------------------------------------------------------------------------------------------------------------Q3
                IWorksheet sheet3 = workbook.Worksheets[2];
                sheet3.Range["A1"].Text = "Name 3 things " + CompanyName + " could do better.";
                sheet3.Range["A1"].CellStyle.Font.Bold = true;
                sheet3.Range["A1"].CellStyle.Font.Size = 18;
                phrase.GroupNumber = 3;
                phrase.SurveyNumber = SurveyNumber;
                IList<DisplayInstancesOfPhrase_Result> DoBetter = phrase.PhrasesUsed();
                sheet3.ImportData(DoBetter, 3, 1, true);
                sheet3.Range["A3:B3"].CellStyle.Font.Bold = true;

                //-------------------------------------------------------------------------------------------------------------Q4
                IWorksheet sheet4 = workbook.Worksheets[3];
                sheet4.Range["A1"].Text = "Roles & Responsibilites";
                sheet4.Range["A1"].CellStyle.Font.Bold = true;
                sheet4.Range["A1"].CellStyle.Font.Size = 18;
                IList<SurveyScoresByGroup_Result> group4 = db.SurveyScoresByGroup(4, SurveyNumber).ToList();
                sheet4.ImportData(group4, 3, 1, true);
                sheet4.Range["A3:H3"].CellStyle.Font.Bold = true;
                lastrow = Convert.ToInt16(sheet4.UsedRange.LastRow);
                rownum = lastrow + 2;
                numRows = survey.CountMatrixQuestions(SurveyNumber, 4);
                b = rownum + numRows;   // this value needs to add the number of group questions to number of rows already on the worksheet
                c = (numRows * 4) + rownum;
                mod.GroupNumber = 4;
                mod.SurveyNumber = SurveyNumber;
                IList<AverageGroupAnswer_Result> data2 = mod.AverageGroupScores();
                sheet4.ImportData(data2, rownum, 1, true);
                IChartShape chart2 = sheet4.Charts.Add();
                chart2.ChartType = ExcelChartType.Bar_Clustered;
                chartplacement = "A" + rownum.ToString() + ":B" + b.ToString();
                chart2.DataRange = sheet4.Range[chartplacement];
                chart2.PrimaryValueAxis.MinimumValue = 0;
                chart2.PrimaryValueAxis.MaximumValue = 5;
                chart2.PrimaryValueAxis.MinorUnit = .5;
                chart2.PrimaryValueAxis.Title = "Average Answer";
                chart2.ChartTitle = "";
                chart2.IsSeriesInRows = false;
                chart2.Legend.Position = ExcelLegendPosition.Bottom;
                chart2.Legend.Delete();
                chart2.TopRow = rownum;
                chart2.BottomRow = c;
                chart2.RightColumn = 15;
                chart2.LeftColumn = 1;
				FillSeriesColor(chart2);

                lastrow = Convert.ToInt16(sheet4.UsedRange.LastRow);
                b = lastrow + 15;
                sheet4.Range["A" + b.ToString()].CellStyle.Font.Bold = true;
                sheet4.Range["A" + b.ToString()].CellStyle.Font.Size = 16;

                IList<ParticpantComments> q4Comments = survey.participantComments(SurveyNumber, 4);
                if (q4Comments.Count > 0)
                {
                    sheet4.ImportData(q4Comments, b, 1, true);
                }

                //-------------------------------------------------------------------------------------------------------------Q5
                IWorksheet sheet5 = workbook.Worksheets[4];
                sheet5.Range["A1"].Text = "Client Engagement";
                sheet5.Range["A1"].CellStyle.Font.Bold = true;
                sheet5.Range["A1"].CellStyle.Font.Size = 18;
                IList<SurveyScoresByGroup_Result> group5 = db.SurveyScoresByGroup(5, SurveyNumber).ToList();
                sheet5.ImportData(group5, 3, 1, true);
                sheet5.Range["A3:H3"].CellStyle.Font.Bold = true;
                lastrow = Convert.ToInt16(sheet5.UsedRange.LastRow);
                rownum = lastrow + 2;
                numRows = survey.CountMatrixQuestions(SurveyNumber, 5);
                b = rownum + numRows;   // this value needs to add the number of group questions to number of rows already on the worksheet
                c = (numRows * 4) + rownum;
                mod.GroupNumber = 5;
                mod.SurveyNumber = SurveyNumber;
                IList<AverageGroupAnswer_Result> data3 = mod.AverageGroupScores();
                sheet5.ImportData(data3, rownum, 1, true);
                IChartShape chart3 = sheet5.Charts.Add();
                chart3.ChartType = ExcelChartType.Bar_Clustered;
                chartplacement = "A" + rownum.ToString() + ":B" + b.ToString();
                chart3.DataRange = sheet5.Range[chartplacement];
                chart3.PrimaryValueAxis.MinimumValue = 0;
                chart3.PrimaryValueAxis.MaximumValue = 5;
                chart3.PrimaryValueAxis.MinorUnit = .5;
                chart3.PrimaryValueAxis.Title = "Average Answer";
                chart3.ChartTitle = "";
                chart3.IsSeriesInRows = false;
                chart3.Legend.Position = ExcelLegendPosition.Bottom;
                chart3.Legend.Delete();
                chart3.TopRow = rownum;
                chart3.BottomRow = c;
                chart3.RightColumn = 15;
                chart3.LeftColumn = 1;
				FillSeriesColor(chart3);

                lastrow = Convert.ToInt16(sheet5.UsedRange.LastRow);
                b = lastrow + 15;
                sheet5.Range["A" + b.ToString()].CellStyle.Font.Bold = true;
                sheet5.Range["A" + b.ToString()].CellStyle.Font.Size = 16;

                IList<ParticpantComments> q5Comments = survey.participantComments(SurveyNumber, 5);
                if (q5Comments.Count > 0)
                {
                    sheet5.ImportData(q5Comments, b, 1, true);
                }


                //-------------------------------------------------------------------------------------------------------------Q6
                IWorksheet sheet6 = workbook.Worksheets[5];
                sheet6.Range["A1"].Text = "What one thing could we do to";
                sheet6.Range["A1"].CellStyle.Font.Bold = true;
                sheet6.Range["A1"].CellStyle.Font.Size = 18;
                //IList<SurveyScoresByGroup_Result> group6 = db.SurveyScoresByGroup(6, SurveyNumber).ToList();
                //sheet6.ImportData(group6, 3, 1, true);
                //sheet6.Range["A3:H3"].CellStyle.Font.Bold = true;
                //lastrow = Convert.ToInt16(sheet6.UsedRange.LastRow);
                //rownum = lastrow + 2;
                //numRows = survey.CountMatrixQuestions(SurveyNumber, 6);
                //b = rownum + numRows;   // this value needs to add the number of group questions to number of rows already on the worksheet
                //mod.GroupNumber = 6;
                //mod.SurveyNumber = SurveyNumber;
                //IList<AverageGroupAnswer_Result> data4 = mod.AverageGroupScores();
                //sheet6.ImportData(data4, rownum, 1, true);
                //IChartShape chart4 = sheet6.Charts.Add();
                //chart4.ChartType = ExcelChartType.Bar_Clustered;
                //chartplacement = "A" + rownum.ToString() + ":B" + b.ToString();
                //chart4.DataRange = sheet6.Range[chartplacement];
                //chart4.PrimaryValueAxis.MinimumValue = 0;
                //chart4.PrimaryValueAxis.MaximumValue = 5;
                //chart4.PrimaryValueAxis.MinorUnit = .5;
                //chart4.PrimaryValueAxis.Title = "Average Answer";
                //chart4.ChartTitle = "";
                //chart4.IsSeriesInRows = false;
                //chart4.Legend.Position = ExcelLegendPosition.Bottom;
                //chart4.Legend.Delete();
                //chart4.TopRow = rownum;
                //chart4.RightColumn = 15;
                //chart4.LeftColumn = 1;

                //lastrow = Convert.ToInt16(sheet6.UsedRange.LastRow);
                //b = lastrow + 15;
                //sheet6.Range["A" + b.ToString()].CellStyle.Font.Bold = true;
                //sheet6.Range["A" + b.ToString()].CellStyle.Font.Size = 16;

                //IList<ParticpantComments> q6Comments = survey.participantComments(SurveyNumber, 6);
                //if (q6Comments.Count > 0)
                //{
                //    sheet6.ImportData(q6Comments, b, 1, true);
                //}

                //-------------------------------------------------------------------------------------------------------------Q7
                IWorksheet sheet7 = workbook.Worksheets[6];
                sheet7.Range["A1"].Text = "Physical Space";
                sheet7.Range["A1"].CellStyle.Font.Bold = true;
                sheet7.Range["A1"].CellStyle.Font.Size = 18;
                IList<SurveyScoresByGroup_Result> group7 = db.SurveyScoresByGroup(7, SurveyNumber).ToList();
                sheet7.ImportData(group7, 3, 1, true);
                sheet7.Range["A3:H3"].CellStyle.Font.Bold = true;
                lastrow = Convert.ToInt16(sheet7.UsedRange.LastRow);
                rownum = lastrow + 2;
                numRows = survey.CountMatrixQuestions(SurveyNumber, 7);
                b = rownum + numRows;   // this value needs to add the number of group questions to number of rows already on the worksheet
                c = (numRows * 5) + rownum;
                mod.GroupNumber = 7;
                mod.SurveyNumber = SurveyNumber;
                IList<AverageGroupAnswer_Result> data7 = mod.AverageGroupScores();
                sheet7.ImportData(data7, rownum, 1, true);
                IChartShape chart7 = sheet7.Charts.Add();
                chart7.ChartType = ExcelChartType.Bar_Clustered;
                chartplacement = "A" + rownum.ToString() + ":B" + b.ToString();
                chart7.DataRange = sheet7.Range[chartplacement];
                chart7.PrimaryValueAxis.MinimumValue = 0;
                chart7.PrimaryValueAxis.MaximumValue = 5;
                chart7.PrimaryValueAxis.MinorUnit = .5;
                chart7.PrimaryValueAxis.Title = "Average Answer";
                chart7.ChartTitle = "";
                chart7.IsSeriesInRows = false;
                chart7.Legend.Position = ExcelLegendPosition.Bottom;
                chart7.Legend.Delete();
                chart7.TopRow = rownum;
                chart7.BottomRow = c;
                chart7.RightColumn = 15;
                chart7.LeftColumn = 1;
				FillSeriesColor(chart7);

                lastrow = Convert.ToInt16(sheet7.UsedRange.LastRow);
                b = lastrow + 18;
                sheet7.Range["A" + b.ToString()].CellStyle.Font.Bold = true;
                sheet7.Range["A" + b.ToString()].CellStyle.Font.Size = 16;

                IList<ParticpantComments> q7Comments = survey.participantComments(SurveyNumber, 7);
                if (q7Comments.Count > 0)
                {
                    sheet7.ImportData(q7Comments, b, 1, true);
                }

                //-------------------------------------------------------------------------------------------------------------Q8
                IWorksheet sheet8 = workbook.Worksheets[7];
                sheet8.Range["A1"].Text = "Collaboration";
                sheet8.Range["A1"].CellStyle.Font.Bold = true;
                sheet8.Range["A1"].CellStyle.Font.Size = 18;
                IList<SurveyScoresByGroup_Result> group8 = db.SurveyScoresByGroup(8, SurveyNumber).ToList();
                sheet8.ImportData(group8, 3, 1, true);
                sheet8.Range["A3:H3"].CellStyle.Font.Bold = true;
                lastrow = Convert.ToInt16(sheet8.UsedRange.LastRow);
                rownum = lastrow + 2;
                numRows = survey.CountMatrixQuestions(SurveyNumber, 8);
                b = rownum + numRows;   // this value needs to add the number of group questions to number of rows already on the worksheet
                c = (numRows * 4) + rownum;
                mod.GroupNumber = 8;
                mod.SurveyNumber = SurveyNumber;
                IList<AverageGroupAnswer_Result> data8 = mod.AverageGroupScores();
                sheet8.ImportData(data8, rownum, 1, true);
                IChartShape chart8 = sheet8.Charts.Add();
                chart8.ChartType = ExcelChartType.Bar_Clustered;
                chartplacement = "A" + rownum.ToString() + ":B" + b.ToString();
                chart8.DataRange = sheet8.Range[chartplacement];
                chart8.PrimaryValueAxis.MinimumValue = 0;
                chart8.PrimaryValueAxis.MaximumValue = 5;
                chart8.PrimaryValueAxis.MinorUnit = .5;
                chart8.PrimaryValueAxis.Title = "Average Answer";
                chart8.ChartTitle = "";
                chart8.IsSeriesInRows = false;
                chart8.Legend.Position = ExcelLegendPosition.Bottom;
                chart8.Legend.Delete();
                chart8.TopRow = rownum;
                chart8.BottomRow = c;
                chart8.RightColumn = 15;
                chart8.LeftColumn = 1;
				FillSeriesColor(chart8);

                lastrow = Convert.ToInt16(sheet8.UsedRange.LastRow);
                b = lastrow + 15;
                sheet8.Range["A" + b.ToString()].CellStyle.Font.Bold = true;
                sheet8.Range["A" + b.ToString()].CellStyle.Font.Size = 16;

                IList<ParticpantComments> q8Comments = survey.participantComments(SurveyNumber, 8);
                if (q8Comments.Count > 0)
                {
                    sheet8.ImportData(q8Comments, b, 1, true);
                }

                //-------------------------------------------------------------------------------------------------------------Q9
                IWorksheet sheet9 = workbook.Worksheets[8];
                sheet9.Range["A1"].Text = "Idea Sharing";
                sheet9.Range["A1"].CellStyle.Font.Bold = true;
                sheet9.Range["A1"].CellStyle.Font.Size = 18;
                IList<SurveyScoresByGroup_Result> group9 = db.SurveyScoresByGroup(9, SurveyNumber).ToList();
                sheet9.ImportData(group9, 3, 1, true);
                sheet9.Range["A3:H3"].CellStyle.Font.Bold = true;
                lastrow = Convert.ToInt16(sheet9.UsedRange.LastRow);
                rownum = lastrow + 2;
                numRows = survey.CountMatrixQuestions(SurveyNumber, 9);
                b = rownum + numRows;   // this value needs to add the number of group questions to number of rows already on the worksheet
                c = (numRows * 4) + rownum;
                mod.GroupNumber = 9;
                mod.SurveyNumber = SurveyNumber;
                IList<AverageGroupAnswer_Result> data9 = mod.AverageGroupScores();
                sheet9.ImportData(data9, rownum, 1, true);
                IChartShape chart9 = sheet9.Charts.Add();
                chart9.ChartType = ExcelChartType.Bar_Clustered;
                chartplacement = "A" + rownum.ToString() + ":B" + b.ToString();
                chart9.DataRange = sheet9.Range[chartplacement];
                chart9.PrimaryValueAxis.MinimumValue = 0;
                chart9.PrimaryValueAxis.MaximumValue = 5;
                chart9.PrimaryValueAxis.MinorUnit = .5;
                chart9.PrimaryValueAxis.Title = "Average Answer";
                chart9.ChartTitle = "";
                chart9.IsSeriesInRows = false;
                chart9.Legend.Position = ExcelLegendPosition.Bottom;
                chart9.Legend.Delete();
                chart9.TopRow = rownum;
                chart9.BottomRow = c;
                chart9.RightColumn = 15;
                chart9.LeftColumn = 1;
				FillSeriesColor(chart9);

                lastrow = Convert.ToInt16(sheet9.UsedRange.LastRow);
                b = lastrow + 15;
                sheet9.Range["A" + b.ToString()].CellStyle.Font.Bold = true;
                sheet9.Range["A" + b.ToString()].CellStyle.Font.Size = 16;

                IList<ParticpantComments> q9Comments = survey.participantComments(SurveyNumber, 9);
                if (q9Comments.Count > 0)
                {
                    sheet9.ImportData(q9Comments, b, 1, true);
                }

                //-------------------------------------------------------------------------------------------------------------Q10
                IWorksheet sheet10 = workbook.Worksheets[9];
                sheet10.Range["A1"].Text = "How do ideas/opportunites get shared within the company.";
                sheet10.Range["A1"].CellStyle.Font.Bold = true;
                sheet10.Range["A1"].CellStyle.Font.Size = 18;
               
                RadioButtonAnswers rba = new RadioButtonAnswers();
                rba.SurveyNumber = SurveyNumber;
                rba.GroupNumber = 10;
                rownum = 3;
                numRows = survey.NumberDifferentResponses(SurveyNumber, 10, 3);  // 3 = Radio Button 
                b = numRows + rownum;   
                IList<GetRadioAnswerOccurances_Result> IdeasRadio = rba.RadioAnswers();
                sheet10.ImportData(IdeasRadio, rownum, 1, true);
                sheet10.Range["A3"].Text = "Method Used";
                sheet10.Range["A3"].CellStyle.Font.Bold = true;
                sheet10.Range["B3"].Text = "Occurances";
                sheet10.Range["B3"].CellStyle.Font.Bold = true;
                IChartShape chart10 = sheet10.Charts.Add();
                chart10.ChartType = ExcelChartType.Pie;
                chart10.ChartTitle = "Methods Used";
                chartplacement = "A3:B"+b.ToString();
                chart10.DataRange = sheet10.Range[chartplacement];
                chart10.IsSeriesInRows = false;
                chart10.Legend.Position = ExcelLegendPosition.Bottom;
                chart10.Series[0].DataPoints.DefaultDataPoint.DataLabels.Size = 14;
                chart10.Series[0].DataPoints.DefaultDataPoint.DataLabels.Color = ExcelKnownColors.White;
                chart10.Series[0].DataPoints.DefaultDataPoint.DataLabels.IsValue = true;
                chart10.Series[0].DataPoints.DefaultDataPoint.DataLabels.IsLegendKey = true;
                chart10.TopRow = 3;
                chart10.BottomRow = 25;
                chart10.LeftColumn = 4;
                chart10.RightColumn = 15;
				FillSeriesColor(chart10);

                lastrow = Convert.ToInt16(sheet10.UsedRange.LastRow);
                b = lastrow + 20;
               
                OtherAnswersListed other = new OtherAnswersListed();
                other.SurveyNumber = SurveyNumber;
                other.GroupNumber = 10;
                IList<GetOtherAnswerOccurance_Result> OtherIdeas = other.OtherAnswers();
                if(OtherIdeas.Count > 0)
                {
                    sheet10.Range["A" + b.ToString()].Text = "Other Responses";
                    sheet10.Range["A" + b.ToString()].CellStyle.Font.Bold = true;
                    sheet10.Range["A" + b.ToString()].CellStyle.Font.Size = 16;
                    sheet10.Range["A" + (b+1).ToString()].Text = "Instances";
                    sheet10.Range["A" + (b + 1).ToString()].CellStyle.Font.Bold = true;
                    sheet10.Range["B" + (b + 1).ToString()].Text = "Method Used";
                    sheet10.Range["B" + (b + 1).ToString()].CellStyle.Font.Bold = true;
                    sheet10.ImportData(OtherIdeas, b + 2, 1, false);
                }

                //-------------------------------------------------------------------------------------------------------------Q11
                IWorksheet sheet11 = workbook.Worksheets[10];
                sheet11.Range["A1"].Text = "Leadership Direction & Engagement";
                sheet11.Range["A1"].CellStyle.Font.Bold = true;
                sheet11.Range["A1"].CellStyle.Font.Size = 18;
                IList<SurveyScoresByGroup_Result> group11 = db.SurveyScoresByGroup(11, SurveyNumber).ToList();
                sheet11.ImportData(group11, 3, 1, true);
                sheet11.Range["A3:H3"].CellStyle.Font.Bold = true;
                lastrow = Convert.ToInt16(sheet11.UsedRange.LastRow);
                rownum = lastrow + 2;
                numRows = survey.CountMatrixQuestions(SurveyNumber, 11);
                b = rownum + numRows;   // this value needs to add the number of group questions to number of rows already on the worksheet
                c = (numRows * 4) + rownum;
                mod.GroupNumber = 11;
                mod.SurveyNumber = SurveyNumber;
                IList<AverageGroupAnswer_Result> data11 = mod.AverageGroupScores();
                sheet11.ImportData(data11, rownum, 1, true);
                IChartShape chart11 = sheet11.Charts.Add();
                chart11.ChartType = ExcelChartType.Bar_Clustered;
                chartplacement = "A" + rownum.ToString() + ":B" + b.ToString();
                chart11.DataRange = sheet11.Range[chartplacement];
                chart11.PrimaryValueAxis.MinimumValue = 0;
                chart11.PrimaryValueAxis.MaximumValue = 5;
                chart11.PrimaryValueAxis.MinorUnit = .5;
                chart11.PrimaryValueAxis.Title = "Average Answer";
                chart11.ChartTitle = "";
                chart11.IsSeriesInRows = false;
                chart11.Legend.Position = ExcelLegendPosition.Bottom;
                chart11.Legend.Delete();
                chart11.TopRow = rownum;
                chart11.BottomRow = c;
                chart11.RightColumn = 15;
                chart11.LeftColumn = 1;
				FillSeriesColor(chart11);

                lastrow = Convert.ToInt16(sheet11.UsedRange.LastRow);
                b = lastrow + 15;
                sheet11.Range["A" + b.ToString()].CellStyle.Font.Bold = true;
                sheet11.Range["A" + b.ToString()].CellStyle.Font.Size = 16;

                IList<ParticpantComments> q11Comments = survey.participantComments(SurveyNumber, 11);
                if (q11Comments.Count > 0)
                {
                    sheet11.ImportData(q11Comments, b, 1, true);
                }

                //-------------------------------------------------------------------------------------------------------------Q12
                IWorksheet sheet12 = workbook.Worksheets[11];
                sheet12.Range["A1"].Text = "Communication Quality & Frequency";
                sheet12.Range["A1"].CellStyle.Font.Bold = true;
                sheet12.Range["A1"].CellStyle.Font.Size = 18;
                IList<SurveyScoresByGroup_Result> group12 = db.SurveyScoresByGroup(12, SurveyNumber).ToList();
                sheet12.ImportData(group12, 3, 1, true);
                sheet12.Range["A3:H3"].CellStyle.Font.Bold = true;
                lastrow = Convert.ToInt16(sheet12.UsedRange.LastRow);
                rownum = lastrow + 2;
                numRows = survey.CountMatrixQuestions(SurveyNumber, 12);
                b = rownum + numRows;   // this value needs to add the number of group questions to number of rows already on the worksheet
                c = (numRows * 4) + rownum;
                mod.GroupNumber = 12;
                mod.SurveyNumber = SurveyNumber;
                IList<AverageGroupAnswer_Result> data12 = mod.AverageGroupScores();
                sheet12.ImportData(data12, rownum, 1, true);
                IChartShape chart12 = sheet12.Charts.Add();
                chart12.ChartType = ExcelChartType.Bar_Clustered;
                chartplacement = "A" + rownum.ToString() + ":B" + b.ToString();
                chart12.DataRange = sheet12.Range[chartplacement];
                chart12.PrimaryValueAxis.MinimumValue = 0;
                chart12.PrimaryValueAxis.MaximumValue = 5;
                chart12.PrimaryValueAxis.MinorUnit = .5;
                chart12.PrimaryValueAxis.Title = "Average Answer";
                chart12.ChartTitle = "";
                chart12.IsSeriesInRows = false;
                chart12.Legend.Position = ExcelLegendPosition.Bottom;
                chart12.Legend.Delete();
                chart12.TopRow = rownum;
                chart12.BottomRow = c;
                chart12.RightColumn = 15;
                chart12.LeftColumn = 1;
				FillSeriesColor(chart12);

                lastrow = Convert.ToInt16(sheet12.UsedRange.LastRow);
                b = lastrow + 15;
                sheet12.Range["A" + b.ToString()].CellStyle.Font.Bold = true;
                sheet12.Range["A" + b.ToString()].CellStyle.Font.Size = 16;

                IList<ParticpantComments> q12Comments = survey.participantComments(SurveyNumber, 12);
                if (q12Comments.Count > 0)
                {
                    sheet12.ImportData(q12Comments, b, 1, true);
                }

                //-------------------------------------------------------------------------------------------------------------Q13
                IWorksheet sheet13 = workbook.Worksheets[12];
                sheet13.Range["A1"].Text = "What methods are typically used for communicating within the company";
                sheet13.Range["A1"].CellStyle.Font.Bold = true;
                sheet13.Range["A1"].CellStyle.Font.Size = 18;
                CheckBoxAnswers cba = new CheckBoxAnswers();
                cba.GroupNumber = 13;
                cba.SurveyNumber = SurveyNumber;
                IList<DisplayCheckBoxInstances_Result> HowCommunicate = cba.CheckAllAnswers();
                rownum = 3;
                numRows = HowCommunicate.Count();
                b = numRows + rownum;
                
                sheet13.ImportData(HowCommunicate, rownum, 1, true);
                IChartShape chart13 = sheet13.Charts.Add();
                chart13.ChartType = ExcelChartType.Pie;
                chart13.ChartTitle = "Methods of Communication Used";
                chartplacement = "A4:B" + b.ToString();
                chart13.DataRange = sheet13.Range[chartplacement];
                chart13.IsSeriesInRows = false;
                chart13.Legend.Position = ExcelLegendPosition.Bottom;
                chart13.Series[0].DataPoints.DefaultDataPoint.DataLabels.Size = 14;
                chart13.Series[0].DataPoints.DefaultDataPoint.DataLabels.Color = ExcelKnownColors.White;
                chart13.Series[0].DataPoints.DefaultDataPoint.DataLabels.IsValue = true;
                chart13.Series[0].DataPoints.DefaultDataPoint.DataLabels.IsLegendKey = true;
                chart13.TopRow = 3;
                chart13.BottomRow = 25;
                chart13.LeftColumn = 4;
                chart13.RightColumn = 15;
				FillSeriesColor(chart13);

                //-------------------------------------------------------------------------------------------------------------Q14
                IWorksheet sheet14 = workbook.Worksheets[13];
                sheet14.Range["A1"].Text = "What is your preferred method of communication";
                sheet14.Range["A1"].CellStyle.Font.Bold = true;
                sheet14.Range["A1"].CellStyle.Font.Size = 18;
                cba.GroupNumber = 14;
                cba.SurveyNumber = SurveyNumber;
                IList<DisplayCheckBoxInstances_Result> PreferCommunicate = cba.CheckAllAnswers();
                rownum = 3;
                numRows = PreferCommunicate.Count();
                b = numRows + rownum;

                sheet14.ImportData(PreferCommunicate, rownum, 1, true);
                IChartShape chart14 = sheet14.Charts.Add();
                chart14.ChartType = ExcelChartType.Pie;
                chart13.ChartTitle = "Preferred Methods of Communication";
                chartplacement = "A4:B" + b.ToString();
                chart14.DataRange = sheet13.Range[chartplacement];
                chart14.IsSeriesInRows = false;
                chart14.Legend.Position = ExcelLegendPosition.Bottom;
                chart14.Series[0].DataPoints.DefaultDataPoint.DataLabels.Size = 14;
                chart14.Series[0].DataPoints.DefaultDataPoint.DataLabels.Color = ExcelKnownColors.White;
                chart14.Series[0].DataPoints.DefaultDataPoint.DataLabels.IsValue = true;
                chart14.Series[0].DataPoints.DefaultDataPoint.DataLabels.IsLegendKey = true;
                chart14.TopRow = 3;
                chart14.BottomRow = 25;
                chart14.LeftColumn = 4;
                chart14.RightColumn = 15;
				FillSeriesColor(chart14);

                //-------------------------------------------------------------------------------------------------------------Q15
                IWorksheet sheet15 = workbook.Worksheets[14];
                sheet15.Range["A1"].Text = "Vision & Values";
                sheet15.Range["A1"].CellStyle.Font.Bold = true;
                sheet15.Range["A1"].CellStyle.Font.Size = 18;
                IList<SurveyScoresByGroup_Result> group15 = db.SurveyScoresByGroup(15, SurveyNumber).ToList();
                sheet15.ImportData(group15, 3, 1, true);
                sheet15.Range["A3:H3"].CellStyle.Font.Bold = true;
                lastrow = Convert.ToInt16(sheet15.UsedRange.LastRow);
                rownum = lastrow + 2;
                numRows = survey.CountMatrixQuestions(SurveyNumber, 15);
                b = rownum + numRows;   // this value needs to add the number of group questions to number of rows already on the worksheet
                c = (numRows * 4) + rownum;
                mod.GroupNumber = 15;
                mod.SurveyNumber = SurveyNumber;
                IList<AverageGroupAnswer_Result> data15 = mod.AverageGroupScores();
                sheet15.ImportData(data15, rownum, 1, true);
                IChartShape chart15 = sheet15.Charts.Add();
                chart15.ChartType = ExcelChartType.Bar_Clustered;
                chartplacement = "A" + rownum.ToString() + ":B" + b.ToString();
                chart15.DataRange = sheet15.Range[chartplacement];
                chart15.PrimaryValueAxis.MinimumValue = 0;
                chart15.PrimaryValueAxis.MaximumValue = 5;
                chart15.PrimaryValueAxis.MinorUnit = .5;
                chart15.PrimaryValueAxis.Title = "Average Answer";
                chart15.ChartTitle = "";
                chart15.IsSeriesInRows = false;
                chart15.Legend.Position = ExcelLegendPosition.Bottom;
                chart15.Legend.Delete();
                chart15.TopRow = rownum;
                chart15.BottomRow = c;
                chart15.RightColumn = 15;
                chart15.LeftColumn = 1;
				FillSeriesColor(chart15);

                lastrow = Convert.ToInt16(sheet15.UsedRange.LastRow);
                b = lastrow + 15;
                sheet15.Range["A" + b.ToString()].CellStyle.Font.Bold = true;
                sheet15.Range["A" + b.ToString()].CellStyle.Font.Size = 16;

                IList<ParticpantComments> q15Comments = survey.participantComments(SurveyNumber, 15);
                if (q15Comments.Count > 0)
                {
                    sheet15.ImportData(q15Comments, b, 1, true);
                }

                //-------------------------------------------------------------------------------------------------------------Q16
                IWorksheet sheet16 = workbook.Worksheets[15];
                sheet16.Range["A1"].Text = "Top 3 to 5 Core Values";
                sheet16.Range["A1"].CellStyle.Font.Bold = true;
                sheet16.Range["A1"].CellStyle.Font.Size = 18;
                phrase.GroupNumber = 16;
                phrase.SurveyNumber = SurveyNumber;
                IList<DisplayInstancesOfPhrase_Result> CoreValues = phrase.PhrasesUsed();
                sheet16.ImportData(CoreValues, 3, 1, true);
                sheet16.Range["A3:B3"].CellStyle.Font.Bold = true;

                //-------------------------------------------------------------------------------------------------------------Q17
                IWorksheet sheet17 = workbook.Worksheets[16];
                sheet17.Range["A1"].Text = "Support & Development";
                sheet17.Range["A1"].CellStyle.Font.Bold = true;
                sheet17.Range["A1"].CellStyle.Font.Size = 18;
                IList<SurveyScoresByGroup_Result> group17 = db.SurveyScoresByGroup(17, SurveyNumber).ToList();
                sheet17.ImportData(group17, 3, 1, true);
                sheet17.Range["A3:H3"].CellStyle.Font.Bold = true;
                lastrow = Convert.ToInt16(sheet17.UsedRange.LastRow);
                rownum = lastrow + 2;
                numRows = survey.CountMatrixQuestions(SurveyNumber, 17);
                b = rownum + numRows;   // this value needs to add the number of group questions to number of rows already on the worksheet
                c = (numRows * 4) + rownum;
                mod.GroupNumber = 8;
                mod.SurveyNumber = SurveyNumber;
                IList<AverageGroupAnswer_Result> data17 = mod.AverageGroupScores();
                sheet17.ImportData(data17, rownum, 1, true);
                IChartShape chart17 = sheet17.Charts.Add();
                chart17.ChartType = ExcelChartType.Bar_Clustered;
                chartplacement = "A" + rownum.ToString() + ":B" + b.ToString();
                chart17.DataRange = sheet17.Range[chartplacement];
                chart17.PrimaryValueAxis.MinimumValue = 0;
                chart17.PrimaryValueAxis.MaximumValue = 5;
                chart17.PrimaryValueAxis.MinorUnit = .5;
                chart17.PrimaryValueAxis.Title = "Average Answer";
                chart17.ChartTitle = "";
                chart17.IsSeriesInRows = false;
                chart17.Legend.Position = ExcelLegendPosition.Bottom;
                chart17.Legend.Delete();
                chart17.TopRow = rownum;
                chart17.BottomRow = c;
                chart17.RightColumn = 15;
                chart17.LeftColumn = 1;
				FillSeriesColor(chart17);

                lastrow = Convert.ToInt16(sheet17.UsedRange.LastRow);
                b = lastrow + 15;
                sheet17.Range["A" + b.ToString()].CellStyle.Font.Bold = true;
                sheet17.Range["A" + b.ToString()].CellStyle.Font.Size = 16;

                IList<ParticpantComments> q17Comments = survey.participantComments(SurveyNumber, 17);
                if (q17Comments.Count > 0)
                {
                    sheet17.ImportData(q17Comments, b, 1, true);
                }

                //-------------------------------------------------------------------------------------------------------------Q18
                IWorksheet sheet18 = workbook.Worksheets[17];
                sheet18.Range["A1"].Text = "Reward & Recognition";
                sheet18.Range["A1"].CellStyle.Font.Bold = true;
                sheet18.Range["A1"].CellStyle.Font.Size = 18;
                IList<SurveyScoresByGroup_Result> group18 = db.SurveyScoresByGroup(18, SurveyNumber).ToList();
                sheet18.ImportData(group18, 3, 1, true);
                sheet18.Range["A3:H3"].CellStyle.Font.Bold = true;
                lastrow = Convert.ToInt16(sheet18.UsedRange.LastRow);
                rownum = lastrow + 2;
                numRows = survey.CountMatrixQuestions(SurveyNumber, 18);
                b = rownum + numRows;   // this value needs to add the number of group questions to number of rows already on the worksheet
                c = (numRows * 4) + rownum;
                mod.GroupNumber = 8;
                mod.SurveyNumber = SurveyNumber;
                IList<AverageGroupAnswer_Result> data18 = mod.AverageGroupScores();
                sheet18.ImportData(data18, rownum, 1, true);
                IChartShape chart18 = sheet18.Charts.Add();
                chart18.ChartType = ExcelChartType.Bar_Clustered;
                chartplacement = "A" + rownum.ToString() + ":B" + b.ToString();
                chart18.DataRange = sheet18.Range[chartplacement];
                chart18.PrimaryValueAxis.MinimumValue = 0;
                chart18.PrimaryValueAxis.MaximumValue = 5;
                chart18.PrimaryValueAxis.MinorUnit = .5;
                chart18.PrimaryValueAxis.Title = "Average Answer";
                chart18.ChartTitle = "";
                chart18.IsSeriesInRows = false;
                chart18.Legend.Position = ExcelLegendPosition.Bottom;
                chart18.Legend.Delete();
                chart18.TopRow = rownum;
                chart18.BottomRow = c;
                chart18.RightColumn = 15;
                chart18.LeftColumn = 1;
				FillSeriesColor(chart18);

                lastrow = Convert.ToInt16(sheet18.UsedRange.LastRow);
                b = lastrow + 15;
                sheet18.Range["A" + b.ToString()].CellStyle.Font.Bold = true;
                sheet18.Range["A" + b.ToString()].CellStyle.Font.Size = 16;

                IList<ParticpantComments> q18Comments = survey.participantComments(SurveyNumber, 18);
                if (q18Comments.Count > 0)
                {
                    sheet18.ImportData(q18Comments, b, 1, true);
                }

                workbook.SaveAs("ReportGroup1.xlsx", HttpContext.ApplicationInstance.Response, ExcelDownloadType.PromptDialog);
                workbook.Close();
                excelEngine.Dispose();
            }

            return View();
        }
		
	    private void FillSeriesColor(IChart chart)
        {

            foreach (IChartSerie serie in chart.Series)
            {
                int dataPointCount = (serie.EnteredDirectlyValues == null) ? serie.Values.Rows.Length : serie.EnteredDirectlyValues.Length;
                for (int dataPointPos = 0; dataPointPos < dataPointCount; dataPointPos++)
                {
                    IChartDataPoint dataPoints = serie.DataPoints[dataPointPos];
                    double value;
                    if (serie.EnteredDirectlyValues == null)
                        value = serie.Values.Rows[dataPointPos].Number;
                    else
                        value = (double)serie.EnteredDirectlyValues.GetValue(dataPointPos);

                    if (value < 1)
                        dataPoints.DataFormat.Fill.ForeColor = Color.Red;
                    else if (value >= 1 && value < 2)
                        dataPoints.DataFormat.Fill.ForeColor = Color.Orange;
                    else if (value >= 2 && value < 3)
                        dataPoints.DataFormat.Fill.ForeColor = Color.Yellow;
                    else if (value >= 3 && value < 4)
                        dataPoints.DataFormat.Fill.ForeColor = Color.FromArgb(153, 255, 204);
                    else if (value >= 4 && value <= 5)
                        dataPoints.DataFormat.Fill.ForeColor = Color.Green;
                }
            }
            
        }

    }

}